Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(343)

Unified Diff: build/android/buildbot_functions.sh

Issue 9605020: Add install script for ant/java for Android and rename sdk install script. (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Add install script for ant/java for Android and rename sdk install script. Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | build/android/envsetup.sh » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: build/android/buildbot_functions.sh
diff --git a/build/android/buildbot_functions.sh b/build/android/buildbot_functions.sh
index 9ad5d492e272e226ae2794e77f030b7c64d53a0a..bb7f6f45552aca282d77165f540676619da8c26b 100755
--- a/build/android/buildbot_functions.sh
+++ b/build/android/buildbot_functions.sh
@@ -22,11 +22,11 @@ function bb_setup_environment {
}
# Install the build deps by running
# build/install-build-deps-android.sh. This may update local tools.
# $1: source root.
function bb_install_build_deps {
echo "@@@BUILD_STEP install build deps android@@@"
- local script="$1/build/install-build-deps-android.sh"
+ local script="$1/build/install-build-deps-android-sdk.sh"
if [[ -f "$script" ]]; then
"$script"
else
@@ -22,11 +22,11 @@ function bb_setup_environment {
}
# Install the build deps by running
-# build/install-build-deps-android.sh. This may update local tools.
+# build/install-build-deps-android-sdk.sh. This may update local tools.
# $1: source root.
function bb_install_build_deps {
« no previous file with comments | « no previous file | build/android/envsetup.sh » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698